@@ -11,6 +11,9 @@ use WWW::Mechanize;
 sub run {
     my ($self) = @_;
 
+    # Disable compression
+    $WWW::Mechanize::HAS_ZLIB = 0;
+
     my $mech = WWW::Mechanize->new(stack_depth => 0);
     $self->run_forked(sub {
         $mech->get(shift);
